package com.ruoyi.logistics.service;

import java.util.List;
import com.ruoyi.logistics.domain.BizMonthQrcodeRecord;

/**
 * 月结二维码使用记录Service接口
 * 
 * @author RuiJing
 * @date 2026-02-12
 */
public interface IBizMonthQrcodeRecordService 
{
    /**
     * 查询月结二维码使用记录
     * 
     * @param qrcodeId 月结二维码使用记录主键
     * @return 月结二维码使用记录
     */
    public BizMonthQrcodeRecord selectBizMonthQrcodeRecordByQrcodeId(Long qrcodeId);

    /**
     * 查询月结二维码使用记录列表
     * 
     * @param bizMonthQrcodeRecord 月结二维码使用记录
     * @return 月结二维码使用记录集合
     */
    public List<BizMonthQrcodeRecord> selectBizMonthQrcodeRecordList(BizMonthQrcodeRecord bizMonthQrcodeRecord);

    /**
     * 新增月结二维码使用记录
     * 
     * @param bizMonthQrcodeRecord 月结二维码使用记录
     * @return 结果
     */
    public int insertBizMonthQrcodeRecord(BizMonthQrcodeRecord bizMonthQrcodeRecord);

    /**
     * 修改月结二维码使用记录
     * 
     * @param bizMonthQrcodeRecord 月结二维码使用记录
     * @return 结果
     */
    public int updateBizMonthQrcodeRecord(BizMonthQrcodeRecord bizMonthQrcodeRecord);

    /**
     * 批量删除月结二维码使用记录
     * 
     * @param qrcodeIds 需要删除的月结二维码使用记录主键集合
     * @return 结果
     */
    public int deleteBizMonthQrcodeRecordByQrcodeIds(Long[] qrcodeIds);

    /**
     * 删除月结二维码使用记录信息
     * 
     * @param qrcodeId 月结二维码使用记录主键
     * @return 结果
     */
    public int deleteBizMonthQrcodeRecordByQrcodeId(Long qrcodeId);
}
